@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -240,9 +243,12 @@ IOUSBMassStorageClass::BulkOnlySendCBWPacket(
 	}
 	
    	STATUS_LOG(("%s: BulkOnlySendCBWPacket sent\n", getName() ));
-	status = GetBulkOutPipe()->Write( boRequestBlock->boPhaseDesc, &boRequestBlock->boCompletion );
+	status = GetBulkOutPipe()->Write(	boRequestBlock->boPhaseDesc,
+										GetTimeoutDuration( boRequestBlock->request ),  // Use the client's timeout for both
+										GetTimeoutDuration( boRequestBlock->request ),
+										&boRequestBlock->boCompletion );
    	STATUS_LOG(("%s: BulkOnlySendCBWPacket returned %d\n", 
-   				getName(),
+   				getName(), 
    				status));
 	return status;
 }
@@ -318,7 +324,10 @@ IOUSBMassStorageClass::BulkOnlyReceiveCSWPacket(
 	boRequestBlock->currentState = nextExecutionState;
 
 	// Retrieve the CSW from the device	
-	status = GetBulkInPipe()->Read( boRequestBlock->boPhaseDesc, &boRequestBlock->boCompletion );
+	status = GetBulkInPipe()->Read( boRequestBlock->boPhaseDesc,
+									GetTimeoutDuration( boRequestBlock->request ),  // Use the client's timeout for both
+									GetTimeoutDuration( boRequestBlock->request ),
+									&boRequestBlock->boCompletion );
 
    	STATUS_LOG(("%s: BulkOnlyReceiveCSWPacket returned %d\n", 
    				getName(), 
@@ -367,10 +376,10 @@ IOUSBMassStorageClass::BulkOnlyExecuteCommandCompletion(
 		case kBulkOnlyCommandSent:
 		{
    			STATUS_LOG(("%s: kBulkOnlyCommandSent returned %d\n", getName(), resultingStatus));
-			
+
 			// Release the memory descriptor for the CBW
 			boRequestBlock->boPhaseDesc->release();
-			
+
 			if(( resultingStatus == kIOReturnDeviceError )
 				|| ( resultingStatus == kIOReturnNotResponding ))
 			{
